import { Injectable } from '@angular/core';
import { Config } from '../../config/config';
import { removeArrayItem } from '../../util/util';
export var ImgLoader = (function () {
    function ImgLoader(config) {
        this.callbacks = [];
        this.ids = 0;
        this.url = config.get('imgWorkerUrl', IMG_WORKER_URL);
    }
    ImgLoader.prototype.load = function (src, cache, callback) {
        if (src) {
            callback.id = this.ids++;
            this.callbacks.push(callback);
            this.worker().postMessage(JSON.stringify({
                id: callback.id,
                src: src,
                cache: cache
            }));
        }
    };
    ImgLoader.prototype.cancelLoad = function (callback) {
        removeArrayItem(this.callbacks, callback);
    };
    ImgLoader.prototype.abort = function (src) {
        if (src) {
            this.worker().postMessage(JSON.stringify({
                src: src,
                type: 'abort'
            }));
        }
    };
    ImgLoader.prototype.worker = function () {
        var _this = this;
        if (!this.wkr) {
            // create the worker
            this.wkr = new Worker(this.url);
            // create worker onmessage handler
            this.wkr.onmessage = function (ev) {
                // we got something back from the web worker
                // let's emit this out to everyone listening
                var msg = JSON.parse(ev.data);
                var callback = _this.callbacks.find(function (cb) { return cb.id === msg.id; });
                if (callback) {
                    callback(msg);
                    removeArrayItem(_this.callbacks, callback);
                }
            };
            // create worker onerror handler
            this.wkr.onerror = function (ev) {
                console.error("ImgLoader, worker " + ev.type + " " + (ev.message ? ev.message : ''));
                _this.callbacks.length = 0;
                _this.wkr.terminate();
                _this.wkr = null;
            };
        }
        // return that hard worker
        return this.wkr;
    };
    ImgLoader.decorators = [
        { type: Injectable },
    ];
    /** @nocollapse */
    ImgLoader.ctorParameters = [
        { type: Config, },
    ];
    return ImgLoader;
}());
var IMG_WORKER_URL = 'build/ion-img-worker.js';
//# sourceMappingURL=img-loader.js.map