import { Injectable } from '@angular/core';
import { Config } from '../../config/config';
import { removeArrayItem } from '../../util/util';
export class ImgLoader {
    constructor(config) {
        this.callbacks = [];
        this.ids = 0;
        this.url = config.get('imgWorkerUrl', IMG_WORKER_URL);
    }
    load(src, cache, callback) {
        if (src) {
            callback.id = this.ids++;
            this.callbacks.push(callback);
            this.worker().postMessage(JSON.stringify({
                id: callback.id,
                src: src,
                cache: cache
            }));
        }
    }
    cancelLoad(callback) {
        removeArrayItem(this.callbacks, callback);
    }
    abort(src) {
        if (src) {
            this.worker().postMessage(JSON.stringify({
                src: src,
                type: 'abort'
            }));
        }
    }
    worker() {
        if (!this.wkr) {
            // create the worker
            this.wkr = new Worker(this.url);
            // create worker onmessage handler
            this.wkr.onmessage = (ev) => {
                // we got something back from the web worker
                // let's emit this out to everyone listening
                const msg = JSON.parse(ev.data);
                const callback = this.callbacks.find(cb => cb.id === msg.id);
                if (callback) {
                    callback(msg);
                    removeArrayItem(this.callbacks, callback);
                }
            };
            // create worker onerror handler
            this.wkr.onerror = (ev) => {
                console.error(`ImgLoader, worker ${ev.type} ${ev.message ? ev.message : ''}`);
                this.callbacks.length = 0;
                this.wkr.terminate();
                this.wkr = null;
            };
        }
        // return that hard worker
        return this.wkr;
    }
}
ImgLoader.decorators = [
    { type: Injectable },
];
/** @nocollapse */
ImgLoader.ctorParameters = [
    { type: Config, },
];
const IMG_WORKER_URL = 'build/ion-img-worker.js';
//# sourceMappingURL=img-loader.js.map