(function (factory) {
    if (typeof module === 'object' && typeof module.exports === 'object') {
        var v = factory(require, exports); if (v !== undefined) module.exports = v;
    }
    else if (typeof define === 'function' && define.amd) {
        define(["require", "exports", '@angular/core', '../../config/config', '../../util/util'], factory);
    }
})(function (require, exports) {
    "use strict";
    var core_1 = require('@angular/core');
    var config_1 = require('../../config/config');
    var util_1 = require('../../util/util');
    var ImgLoader = (function () {
        function ImgLoader(config) {
            this.callbacks = [];
            this.ids = 0;
            this.url = config.get('imgWorkerUrl', IMG_WORKER_URL);
        }
        ImgLoader.prototype.load = function (src, cache, callback) {
            if (src) {
                callback.id = this.ids++;
                this.callbacks.push(callback);
                this.worker().postMessage(JSON.stringify({
                    id: callback.id,
                    src: src,
                    cache: cache
                }));
            }
        };
        ImgLoader.prototype.cancelLoad = function (callback) {
            util_1.removeArrayItem(this.callbacks, callback);
        };
        ImgLoader.prototype.abort = function (src) {
            if (src) {
                this.worker().postMessage(JSON.stringify({
                    src: src,
                    type: 'abort'
                }));
            }
        };
        ImgLoader.prototype.worker = function () {
            var _this = this;
            if (!this.wkr) {
                // create the worker
                this.wkr = new Worker(this.url);
                // create worker onmessage handler
                this.wkr.onmessage = function (ev) {
                    // we got something back from the web worker
                    // let's emit this out to everyone listening
                    var msg = JSON.parse(ev.data);
                    var callback = _this.callbacks.find(function (cb) { return cb.id === msg.id; });
                    if (callback) {
                        callback(msg);
                        util_1.removeArrayItem(_this.callbacks, callback);
                    }
                };
                // create worker onerror handler
                this.wkr.onerror = function (ev) {
                    console.error("ImgLoader, worker " + ev.type + " " + (ev.message ? ev.message : ''));
                    _this.callbacks.length = 0;
                    _this.wkr.terminate();
                    _this.wkr = null;
                };
            }
            // return that hard worker
            return this.wkr;
        };
        ImgLoader.decorators = [
            { type: core_1.Injectable },
        ];
        /** @nocollapse */
        ImgLoader.ctorParameters = [
            { type: config_1.Config, },
        ];
        return ImgLoader;
    }());
    exports.ImgLoader = ImgLoader;
    var IMG_WORKER_URL = 'build/ion-img-worker.js';
});
//# sourceMappingURL=img-loader.js.map